@@ -5,7 +5,7 @@ import requests
 import typer
 import os
 
-from .commands import auth, filter, directory, dashboard, settings, cid
+from .commands import auth, filter, directory, dashboard, settings, cid, setup
 
 app = typer.Typer()
 
@@ -15,3 +15,4 @@ app.add_typer(directory.app, name="directory")
 app.add_typer(dashboard.app, name="dashboard")
 app.add_typer(settings.app, name="settings")
 app.add_typer(cid.app, name="cid")
+app.add_typer(setup.app, name="setup")
